@@ -34,8 +34,8 @@ else:
         soname = "libxcb.so"
 lib = ffi.dlopen(soname)
 
-__xcb_proto_version__ = "1.15.2"
-__version__ = "1.4.0"
+__xcb_proto_version__ = "1.17.0"
+__version__ = "1.6.0"
 
 X_PROTOCOL = lib.X_PROTOCOL
 X_PROTOCOL_REVISION = lib.X_PROTOCOL_REVISION
@@ -178,6 +178,10 @@ class XcffibException(Exception):
     pass
 
 
+class XcffibNotImplemented(XcffibException, NotImplementedError):
+    pass
+
+
 class ConnectionException(XcffibException):
     REASONS = {
         lib.XCB_CONN_ERROR: (
@@ -458,6 +462,11 @@ class List(Protobj):
         except TypeError:
             return ''.join(chr(i) for i in self)
 
+    def to_nullsep_string(self) -> list[str]:
+        """ A helper for converting a List of chars to a list of native
+        strings, starting a new string each time a null (i.e. \\x00) is seen. """
+        return self.to_string().split("\x00")
+
     def to_utf8(self):
         return b''.join(self).decode('utf-8')
 
